@@ -50,7 +50,7 @@ def read_and_filter_alns(
         aln,
         sep="\t",
         header=False,
-        nthreads=32,
+        nthreads=threads,
         columns=col_names[0],
     )
     aln[dt.bool8] = dt.int32
@@ -416,3 +416,22 @@ def aggregate_gene_abundances(mapping_file, gene_abundances, threads=1):
         mappings_agg = mappings_agg.reset_index("group")
         mappings_agg.rename({"count": "n_genes"}, axis=1, inplace=True)
         return mappings, mappings_agg
+
+
+def convert_to_anvio(df, annotation_source):
+    # gene_id	enzyme_accession	source	coverage	detection
+    # Select and rename columns from pandas dataframe
+    df = df.copy()
+    df["group"] = df["group"].str.replace("ko:", "")
+    df["source"] = annotation_source
+    df = df[["reference", "group", "source", "depth_mean", "breadth"]]
+    df.rename(
+        columns={
+            "reference": "gene_id",
+            "group": "enzyme_accession",
+            "depth_mean": "coverage",
+            "breadth": "detection",
+        },
+        inplace=True,
+    )
+    return df
